==> haskell-yesod-static-1.6.1.0-318-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-static
version:              1.6.1.0
visibility:           public
id:                   yesod-static-1.6.1.0-EOELCyrnamM90CfkLEBpsw
key:                  yesod-static-1.6.1.0-EOELCyrnamM90CfkLEBpsw
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>

category:             Web, Yesod
abi:                  5833fb8f824f8964a0826ac5d116f0c9
exposed:              True
exposed-modules:
    Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Css.AbsoluteUrl
    Yesod.EmbeddedStatic.Generators Yesod.EmbeddedStatic.Types
    Yesod.Static

hidden-modules:
    Yesod.EmbeddedStatic.Internal Yesod.EmbeddedStatic.Css.Util

import-dirs:          /usr/lib/ghc-9.0.1/site-local/yesod-static-1.6.1.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/yesod-static-1.6.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/yesod-static-1.6.1.0
hs-libraries:         HSyesod-static-1.6.1.0-EOELCyrnamM90CfkLEBpsw
depends:
    async-2.2.3-KG7Du60y7DvAqBDAYoSjqL
    attoparsec-0.14.1-FCw2YbaswCt6roS8dkagL4 base-4.15.0.0
    base64-bytestring-1.2.1.0-GF7RNKVUXzr7ftO0CMZbPs
    blaze-builder-0.4.2.1-1jqIYnOFfUgLYlL3E7ErdB bytestring-0.10.12.1
    conduit-1.3.4.2-AKStIHaEJrWIIUuGNNY4Rl containers-0.6.4.1
    cryptonite-0.29-9t1m9WkRw4NHt6hLWOfmFh
    cryptonite-conduit-0.2.2-ExJYLqSKSDK90zjXBRgGMc
    css-text-0.1.3.0-FmH2UVwmZNM4iRqIVAaNha
    data-default-0.7.1.1-8aGzV3AyDr077p6b91gXPe directory-1.3.6.1
    file-embed-0.0.14.0-DpVDNlFaM0M9fTuZiTfuRf filepath-1.4.2.1
    hashable-1.3.3.0-LgC2GKp34OLEabneGtyuCb
    hjsmin-0.2.0.4-29brTTC93yJ6BljwVURdf7
    http-types-0.12.3-GbuqI8dbngCJpBlxNWvblX
    memory-0.16.0-CGaPOmXCTce28vOCDDnDFr
    mime-types-0.1.0.9-5oy1hKbeK2pJX1lm5e9fjm process-1.6.11.0
    template-haskell-2.17.0.0 text-1.2.4.1 transformers-0.5.6.2
    unix-compat-0.5.3-CsWJk3UHZrh7lbWn5tdOhn
    unordered-containers-0.2.14.0-Wie4T3gD5k18ShmuaDNll
    wai-3.2.3-3b05xVWcdqf1yAlmx9fZeh
    wai-app-static-3.1.7.2-A1YSEsBGWGW8qYopEJMe2K
    yesod-core-1.6.21.0-6Yac2WEK9Vg4GPxf1gyxIx

haddock-interfaces:
    /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock

haddock-html:         /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-static-1.6.1.0-323-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-static
version:              1.6.1.0
visibility:           public
id:                   yesod-static-1.6.1.0-AZkLTcSNLLsC2dCPWQXckW
key:                  yesod-static-1.6.1.0-AZkLTcSNLLsC2dCPWQXckW
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>

category:             Web, Yesod
abi:                  b7d4ca532e7107fab37ee4c0bd600245
exposed:              True
exposed-modules:
    Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Css.AbsoluteUrl
    Yesod.EmbeddedStatic.Generators Yesod.EmbeddedStatic.Types
    Yesod.Static

hidden-modules:
    Yesod.EmbeddedStatic.Internal Yesod.EmbeddedStatic.Css.Util

import-dirs:          /usr/lib/ghc-9.0.1/site-local/yesod-static-1.6.1.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/yesod-static-1.6.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/yesod-static-1.6.1.0
hs-libraries:         HSyesod-static-1.6.1.0-AZkLTcSNLLsC2dCPWQXckW
depends:
    async-2.2.3-9kX48PHnvdD9PjixjHg39U
    attoparsec-0.14.1-EcyJzfZhZzx4rFmzSXlwR7 base-4.15.0.0
    base64-bytestring-1.2.1.0-3y8bVgj4ClGFIgxpge9J2V
    blaze-builder-0.4.2.2-Iw4q9HoGXXULmCBD2udQGP bytestring-0.10.12.1
    conduit-1.3.4.2-CpnfzB5xaoUDvaJR7w9kCQ containers-0.6.4.1
    cryptonite-0.29-Ael7JaBLzwtAWHfQYnAVOO
    cryptonite-conduit-0.2.2-9n1uhjqTTje7xCA4KrOWeL
    css-text-0.1.3.0-IznGIcNJewo9crqEAIqUMz
    data-default-0.7.1.1-9pDbF71G48YK8T0Zltgcr6 directory-1.3.6.1
    file-embed-0.0.14.0-DpVDNlFaM0M9fTuZiTfuRf filepath-1.4.2.1
    hashable-1.3.3.0-23uoxU4x6MLFe9vf4ULvQk
    hjsmin-0.2.0.4-BoWdQK9YE1gGiVHPXYbxsY
    http-types-0.12.3-Jw2zWV16E9KCVTOWYhAS3k
    memory-0.16.0-CGaPOmXCTce28vOCDDnDFr
    mime-types-0.1.0.9-5oy1hKbeK2pJX1lm5e9fjm process-1.6.11.0
    template-haskell-2.17.0.0 text-1.2.4.1 transformers-0.5.6.2
    unix-compat-0.5.3-CsWJk3UHZrh7lbWn5tdOhn
    unordered-containers-0.2.14.0-7LMDP5QPSZY4o6Vs5H6SAe
    wai-3.2.3-L3wgyssiaHBG0Azbs3MIRI
    wai-app-static-3.1.7.2-FlzbsZqkS58ncdaB08JUM
    yesod-core-1.6.21.0-Du6krcr0amQ562jCBVKdhb

haddock-interfaces:
    /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock

haddock-html:         /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
